@@ -1,6 +1,6 @@
 var searchData=
 [
   ['map_0',['Map',['../classlibcamera_1_1ControlInfoMap.html#a737e0a528fd58dd5d4f976633322b0fb',1,'libcamera::ControlInfoMap']]],
-  ['mapflags_1',['MapFlags',['../classlibcamera_1_1File.html#ab408d863e2a0191023b7368cb52213ef',1,'libcamera::File::MapFlags()'],['../classlibcamera_1_1MappedFrameBuffer.html#a6b4da3269d4616524f6cc458876a8fd0',1,'libcamera::MappedFrameBuffer::MapFlags()']]],
+  ['mapflags_1',['MapFlags',['../classlibcamera_1_1File.html#ab408d863e2a0191023b7368cb52213ef',1,'libcamera::File::MapFlags'],['../classlibcamera_1_1MappedFrameBuffer.html#a6b4da3269d4616524f6cc458876a8fd0',1,'libcamera::MappedFrameBuffer::MapFlags']]],
   ['module_2',['Module',['../classlibcamera_1_1ipa_1_1Algorithm.html#ac52491716c9cd932770dc1a02d7d9b25',1,'libcamera::ipa::Algorithm']]]
 ];
